# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 操作进行中，请稍后重试。
FAILEDOPERATION_TRYLATER = 'FailedOperation.TryLater'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 任务Id不存在。
INVALIDPARAMETERVALUE_NOTASKID = 'InvalidParameterValue.NoTaskId'

# 超过配额限制。
LIMITEXCEEDED = 'LimitExceeded'

# 资源被占用。
RESOURCEINUSE = 'ResourceInUse'

# 资源不存在。
RESOURCENOTFOUND = 'ResourceNotFound'

# 资源不可用。
RESOURCEUNAVAILABLE = 'ResourceUnavailable'

# 资源售罄。
RESOURCESSOLDOUT = 'ResourcesSoldOut'

# 未授权操作。
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
